@@ -1,7 +1,8 @@
 package App::Mobirc::Plugin::HTMLFilter::CompressHTML;
 # vim:expandtab:
 use strict;
-use MooseX::Plaggerize::Plugin;
+use warnings;
+use App::Mobirc::Plugin;
 use App::Mobirc::Util;
 use App::Mobirc::Validator;
 
