@@ -10,12 +10,28 @@ my $map = {
     authorize => [
         { can => 'register' },
         { isa => 'App::Mobirc' },
-        { isa => 'HTTP::Engine::Compat::Context' },
+        { isa => 'Plack::Request' },
     ],
     response_filter => [
         { can => 'register' },
         { isa => 'App::Mobirc' },
-        { isa => 'HTTP::Engine::Compat::Context' },
+        { isa => 'Plack::Response' },
+    ],
+    request_filter => [
+        { can => 'register' },
+        { isa => 'App::Mobirc' },
+        { isa => 'Plack::Request' },
+    ],
+    httpd => [
+        { can => 'register' },
+        { isa => 'App::Mobirc' },
+        { isa => 'Plack::Request' },
+    ],
+    html_filter => [
+        { can => 'register' },
+        { isa => 'App::Mobirc' },
+        { isa => 'Plack::Request' },
+        { type => SCALAR },
     ],
 };
 
